class B:
    def test(self, a: int) -> bool:
        """Test.
        Args:
            a: Argument
        """
        return False
